@@ -1,14 +1,14 @@
 # ABSTRACT: turn WGS84 coordinates into three word addresses and vice-versa using what3words.com HTTPS API
 
 package Geo::What3Words;
-$Geo::What3Words::VERSION = '2.1.4';
+$Geo::What3Words::VERSION = '2.1.5';
 use strict;
 use warnings;
-use LWP::UserAgent;
 use Cpanel::JSON::XS;
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 use Encode qw( decode_utf8 );
+use HTTP::Tiny;
 use Net::Ping;
 use Net::Ping::External;
 use Ref::Util qw( is_hashref is_coderef );
@@ -30,7 +30,7 @@ sub new {
 
   ## _ua is used for testing. But could also be used to
   ## set proxies or such
-  $self->{ua} = $params{ua} || LWP::UserAgent->new;
+  $self->{ua} = $params{ua} || HTTP::Tiny->new;
 
   my $version  = $Geo::What3Words::VERSION || '';
   $self->{ua}->agent("Perl Geo::What3Words $version");
@@ -151,7 +151,7 @@ sub _query_remote_api {
     return;
   }
 
-  my $json = $response->decoded_content;
+  my $json = $response->content;
   $json = decode_utf8($json);
   $self->_log($json);
 
@@ -188,7 +188,7 @@ Geo::What3Words - turn WGS84 coordinates into three word addresses and vice-vers
 
 =head1 VERSION
 
-version 2.1.4
+version 2.1.5
 
 =head1 SYNOPSIS
 
